CREATE PROCEDURE dbo.GetOrderInfo
	@SalesOrderID int
AS
	SELECT *
	FROM Sales.SalesOrderHeader soh
    JOIN Sales.SalesOrderDetail sod ON
		soh.SalesOrderID = sod.SalesOrderID
	WHERE soh.SalesOrderID = @SalesOrderID
GO

CREATE PROCEDURE dbo.ReportByProduct
AS
	SELECT ProductID, COUNT(*) as RecordsCount, SUM(LineTotal) as LineTotal
	FROM Sales.SalesOrderDetail
	GROUP BY ProductID
go

create procedure dbo.GetOrderInfo_mem
	@SalesOrderID int
with native_compilation, schemabinding, execute as owner
as
begin atomic
with (transaction isolation level=snapshot, language=N'us_english')

	SELECT
		soh.[SalesOrderID]
      ,soh.[RevisionNumber]
      ,soh.[OrderDate]
      ,soh.[DueDate]
      ,soh.[ShipDate]
      ,soh.[Status]
      ,soh.[OnlineOrderFlag]
      ,soh.[SalesOrderNumber]
      ,soh.[PurchaseOrderNumber]
      ,soh.[AccountNumber]
      ,soh.[CustomerID]
      ,soh.[SalesPersonID]
      ,soh.[TerritoryID]
      ,soh.[BillToAddressID]
      ,soh.[ShipToAddressID]
      ,soh.[ShipMethodID]
      ,soh.[CreditCardID]
      ,soh.[CreditCardApprovalCode]
      ,soh.[CurrencyRateID]
      ,soh.[SubTotal]
      ,soh.[TaxAmt]
      ,soh.[Freight]
      ,soh.[TotalDue]
      ,soh.[Comment]
      ,soh.[rowguid]
      ,soh.[ModifiedDate]
	  ,sod.[SalesOrderID]
      ,sod.[SalesOrderDetailID]
      ,sod.[CarrierTrackingNumber]
      ,sod.[OrderQty]
      ,sod.[ProductID]
      ,sod.[SpecialOfferID]
      ,sod.[UnitPrice]
      ,sod.[UnitPriceDiscount]
      ,sod.[LineTotal]
      ,sod.[rowguid]
      ,sod.[ModifiedDate]
	FROM Sales.SalesOrderHeader_mem soh
    JOIN Sales.SalesOrderDetail_mem sod ON
		soh.SalesOrderID = sod.SalesOrderID
	WHERE soh.SalesOrderID = @SalesOrderID

end
go

DROP PROCEDURE dbo.ReportByProduct_mem
go
CREATE PROCEDURE dbo.ReportByProduct_mem
with native_compilation, schemabinding, execute as owner
as
begin atomic
with (transaction isolation level=snapshot, language=N'us_english')
	SELECT ProductID, COUNT(*) as RecordsCount, SUM(LineTotal) as LineTotal
	FROM Sales.SalesOrderDetail_mem
	GROUP BY ProductID
end
go

declare @SalesOrderID int = RAND(CHECKSUM(NEWID())) * 32000 + 43659
exec dbo.GetOrderInfo @SalesOrderID

exec dbo.ReportByProduct


