--======================================================
-- Create Memory Optimized Table Template
-- Use the Specify Values for Template Parameters command (Ctrl-Shift-M) to fill in the parameter values below.
-- This template creates a memory optimized table and hash indexes on the memory optimized table.
-- The database must have a MEMORY_OPTIMIZED_DATA filegroup before the memory optimized table can be created.
--======================================================

USE AdventureWorks2012_MEM
GO


CREATE TABLE dbo.test_load
(
	id int not null, 
	n char(100) not null,

   CONSTRAINT pk_test_load PRIMARY KEY NONCLUSTERED HASH (id) WITH (BUCKET_COUNT = 1024),
) WITH (MEMORY_OPTIMIZED = ON, DURABILITY = SCHEMA_AND_DATA)
GO

CREATE TABLE dbo.test_load2
(
	id int not null, 
	n char(100) not null,

   CONSTRAINT pk_test_load2 PRIMARY KEY NONCLUSTERED HASH (id) WITH (BUCKET_COUNT = 1024),
) WITH (MEMORY_OPTIMIZED = ON, DURABILITY = SCHEMA_ONLY)
GO

USE AdventureWorks2012_HDD
GO


CREATE TABLE dbo.test_load
(
	id int not null, 
	n char(100) not null,

   CONSTRAINT pk_test_load PRIMARY KEY CLUSTERED (id),
)
GO

declare @i int = 1
while @i <= 100000
begin
	insert into [dbo].[test_load2]
	values (@i, replicate('a', 100))
	set @i = @i + 1
end

delete from [dbo].[test_load]
delete from [dbo].[test_load2]
truncate table AdventureWorks2012_HDD.[dbo].[test_load]

-- 35 - hdd
-- 27 - mem sad
-- 4 - mem so


-- hdd     133333.33 rows per sec.
-- mem sad 168350.17 rows per sec.
-- mem so  336700.34 rows per sec.


select * from sys.dm_db_xtp_checkpoint
select * from sys.dm_db_xtp_checkpoint_files
select * from sys.dm_xtp_consumer_memory_usage
select * from sys.dm_db_xtp_gc_cycles_stats
select * from sys.dm_xtp_gc_stats
select * from sys.dm_xtp_memory_stats
select * from sys.dm_xtp_system_memory_consumers order by allocated_bytes desc
select * from sys.dm_xtp_threads
select * from sys.dm_xtp_transaction_stats
select * from sys.dm_db_xtp_index_stats
select * from sys.dm_db_xtp_memory_consumers
select * from ys.dm_db_xtp_object_stats
select * from ys.dm_db_xtp_transactions
select * from sys.dm_db_xtp_table_memory_stats

create view dbo.vMyView
as
select * from dbo.test_load
union all
select * from dbo.test_load_hdd

select *
from dbo.vMyView
